.. _all-salt.fileserver:

=======================================
Full list of builtin fileserver modules
=======================================

.. currentmodule:: salt.fileserver

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    gitfs
    hgfs
    roots
    s3fs
    minionfs
